idlefw/plugins/wrtdataplugin/inc/wrtdataplugin.h
branchRCL_3
changeset 64 b276298d5729
parent 59 a0713522ab97
child 74 edd621764147
--- a/idlefw/plugins/wrtdataplugin/inc/wrtdataplugin.h	Wed Apr 14 16:16:44 2010 +0300
+++ b/idlefw/plugins/wrtdataplugin/inc/wrtdataplugin.h	Tue Apr 27 16:57:49 2010 +0300
@@ -151,12 +151,7 @@
      * @see CHsContentPublisher
      */    
     void HandleEvent( const TDesC& aEventName, const TDesC& aParam );
-    
-    /**
-     * @see CHsContentPublisher
-     */    
-    TBool HasMenuItem( const TDesC& aMenuItem );
-         
+
 public:
 
     /**
@@ -265,16 +260,21 @@
      */
     TPluginNetworkStatus NetworkStatus() const;
     
+    /**
+    * Creates initial data republishing timer if needed and starts it
+    */
+    void StartTimer();
+
 private:
     // new functions
     
     /**
     * Publishes widget's texts and images
     *
     * @param void
     * @return void
     */
-    void PublishL();
+    void PublishInitialDataL();
         
 	/**
 	* Resolves skin item id and Mif id from pattern 
@@ -290,7 +290,32 @@
 	*/
 	TBool ResolveSkinIdAndMifId( const TDesC& aPath, TAknsItemID& aItemId,
 	        TInt& aMifId, TInt& aMaskId, TDes& aFilename );
-        
+
+    /**
+    * Cancels transaction in case of leave
+    *
+    * @param aObserver Transaction target
+    */
+    static void CancelTransaction( TAny* aObserver );
+  
+    /**
+    * Cancels initial data republishing timer
+    */
+    void CancelTimer();
+
+    /**
+    * Stops and deletes initial data republishing timer. 
+    */
+    void StopTimer();
+
+    /**
+    * Timeout callback from timer. Used if publishing of initial data has failed.
+    *
+    * @param aPtr Contains pointer to instance of this class 
+    */
+    static TInt Timeout( TAny* aPtr );
+
+
 private: 
     // data
 
@@ -314,6 +339,8 @@
     TPluginStates iPluginState;
     /** File server session handle, owned */
     RFs iRfs;
+    /** Timer for initial data republishing, owned */
+    CPeriodic* iTimer;
     };
 
 #endif // WRTDATAPLUGIN_H
@@ -265,16 +260,21 @@
     
     /**
-    * Publishes widget's texts and images
+    * Publishes widget's initial texts and images
     *
     * @param void